@@ -38,6 +38,7 @@ type LoadBalancersService interface {
 	RemoveDroplets(lbID string, dIDs ...int) error
 	AddForwardingRules(lbID string, rules ...godo.ForwardingRule) error
 	RemoveForwardingRules(lbID string, rules ...godo.ForwardingRule) error
+	PurgeCache(lbID string) error
 }
 
 var _ LoadBalancersService = &loadBalancersService{}
@@ -133,3 +134,8 @@ func (lbs *loadBalancersService) RemoveForwardingRules(lbID string, rules ...god
 	_, err := lbs.client.LoadBalancers.RemoveForwardingRules(context.TODO(), lbID, rules...)
 	return err
 }
+
+func (lbs *loadBalancersService) PurgeCache(lbID string) error {
+	_, err := lbs.client.LoadBalancers.PurgeCache(context.TODO(), lbID)
+	return err
+}
