@@ -69,6 +69,9 @@ var _ = suite("compute/droplet/create", func(t *testing.T, when spec.G, it spec.
 				// since we've successfully tested all the behavior
 				// at this point
 				w.Write([]byte(dropletCreateResponse))
+			case "/v2/projects/00000000-0000-4000-8000-000000000000":
+				w.WriteHeader(http.StatusOK)
+				w.Write([]byte(getProjectResponse))
 			case "/v2/projects/00000000-0000-4000-8000-000000000000/resources":
 				auth := req.Header.Get("Authorization")
 				if auth != "Bearer some-magic-token" {
@@ -235,6 +238,47 @@ var _ = suite("compute/droplet/create", func(t *testing.T, when spec.G, it spec.
 			})
 		}
 	})
+	when("the backup policy is passed", func() {
+		it("polls until the droplet is created", func() {
+			cmd := exec.Command(builtBinaryPath,
+				"-t", "some-magic-token",
+				"-u", server.URL,
+				"compute",
+				"droplet",
+				"create",
+				"backup-policy-on-name",
+				"--image", "a-test-image",
+				"--region", "a-test-region",
+				"--size", "a-test-size",
+				"--vpc-uuid", "00000000-0000-4000-8000-000000000000",
+				"--enable-backups",
+				"--backup-policy-plan", "weekly",
+				"--backup-policy-hour", "4",
+				"--backup-policy-weekday", "MON",
+			)
+
+			output, err := cmd.CombinedOutput()
+			expect.NoError(err, fmt.Sprintf("received error output: %s", output))
+			expect.Equal(strings.TrimSpace(dropletCreateOutput), strings.TrimSpace(string(output)))
+
+			request := &struct {
+				Name    string
+				Image   string
+				Region  string
+				Size    string
+				VPCUUID string `json:"vpc_uuid"`
+			}{}
+
+			err = json.Unmarshal(reqBody, request)
+			expect.NoError(err)
+
+			expect.Equal("backup-policy-on-name", request.Name)
+			expect.Equal("a-test-image", request.Image)
+			expect.Equal("a-test-region", request.Region)
+			expect.Equal("a-test-size", request.Size)
+			expect.Equal("00000000-0000-4000-8000-000000000000", request.VPCUUID)
+		})
+	})
 })
 
 const (
@@ -286,7 +330,20 @@ const (
   ]
 }
 `
-
+	getProjectResponse = `{
+		"project": {
+			"id": "00000000-0000-4000-8000-000000000000",
+			"owner_uuid": "00000000-0000-4000-8000-000000000000",
+			"owner_id": 258992,
+			"name": "some-project-name",
+			"description": "some-description",
+			"purpose": "some-purpose",
+			"environment": "Production",
+			"created_at": "2018-09-27T20:10:35Z",
+			"updated_at": "2018-09-27T20:10:35Z",
+			"is_default": false
+		}
+	}`
 	dropletCreateOutput = `
 ID      Name                 Public IPv4    Private IPv4    Public IPv6    Memory    VCPUs    Disk    Region              Image                          VPC UUID                                Status    Tags    Features    Volumes
 1111    some-droplet-name    1.2.3.4        7.7.7.7                        12        13       15      some-region-slug    some-distro some-image-name    00000000-0000-4000-8000-000000000000    active    yes     remotes     some-volume-id
