@@ -20,6 +20,7 @@ mockgen -source domains.go -package=mocks DomainService > mocks/DomainService.go
 mockgen -source droplet_actions.go -package=mocks DropletActionsService > mocks/DropletActionService.go
 mockgen -source droplet_autoscale.go -package=mocks DropletAutoscaleService > mocks/DropletAutoscaleService.go
 mockgen -source droplets.go -package=mocks DropletsService > mocks/DropletsService.go
+mockgen -source vpc_nat_gateways.go -package=mocks VPCNATGatewaysService > mocks/VPCNATGatewaysService.go
 mockgen -source firewalls.go -package=mocks FirewallsService > mocks/FirewallsService.go
 mockgen -source image_actions.go -package=mocks ImageActionsService > mocks/ImageActionsService.go
 mockgen -source images.go -package=mocks ImageService > mocks/ImageService.go
@@ -46,4 +47,8 @@ mockgen -source monitoring.go -package=mocks MonitoringService > mocks/Monitorin
 mockgen -source reserved_ip_actions.go -package=mocks ReservedIPActionsService > mocks/ReservedIPActionsService.go
 mockgen -source reserved_ips.go -package=mocks ReservedIPsService > mocks/ReservedIPsService.go
 mockgen -source serverless.go -package=mocks ServerlessService > mocks/ServerlessService.go
-mockgen -source partner_interconnect_attachments.go  -package=mocks PartnerInterconnectAttachmentsService > mocks/PartnerInterconnectAttachmentsService.go
+mockgen -source partner_network_connect.go  -package=mocks PartnerAttachmentsService > mocks/PartnerAttachmentsService.go
+mockgen -source spaces_keys.go -package=mocks SpacesKeysService > mocks/SpacesKeysService.go
+mockgen -source genai.go -package=mocks GenAIService > mocks/GenAIService.go
+mockgen -source nfs.go -package=mocks NfsService > mocks/NfsService.go
+mockgen -source nfs_actions.go -package=mocks NfsActionsService > mocks/NfsActionsService.go
